@@ -55,13 +55,12 @@ impl AppBuilder {
             for (action_name, desc) in actions {
                 let action = match &desc.type_ {
                     Some(action_type) => {
-                        let t = VariantTy::new(&action_type).expect(&format!(
-                            "Wrong type for action '{}': {:?}",
-                            action_name, action_type
-                        ));
-                        SimpleAction::new(&action_name, Some(&t))
+                        let t = VariantTy::new(action_type).unwrap_or_else(|_| {
+                            panic!("Wrong type for action '{}': {:?}", action_name, action_type)
+                        });
+                        SimpleAction::new(action_name, Some(t))
                     }
-                    None => SimpleAction::new(&action_name, None),
+                    None => SimpleAction::new(action_name, None),
                 };
 
                 #[cfg(feature = "store")]
@@ -134,7 +133,7 @@ pub fn builder(cargo_toml: &[u8], resources: &[u8]) -> AppBuilder {
     let app = gtk::Application::builder()
         .application_id(&app_desc.id)
         .build();
-    let resource_base_path = format!("/{}/", app_desc.id.replace(".", "/"));
+    let resource_base_path = format!("/{}/", app_desc.id.replace('.', "/"));
     app.set_resource_base_path(Some(&resource_base_path));
 
     load_resources(resources);
